```bash
📂 src/
└  📂 version_pioneer/
   │  📂 cli/                       # Command Line Interface
   │  📂 api/                       # Rewrite of CLI to be used as a library
   │  📂 utils/                     # Difference between the API is that it provides useful functions that are not exposed with CLI.
   │  📂 build/                     # Build backend plugins
   └  🐍 versionscript.py    # Core logic for getting version from Version Control System.
```
